﻿using Rhino;
using Rhino.Commands;
using Rhino.Geometry;
using Rhino.Input;
using Rhino.Input.Custom;
using System;
using System.Collections.Generic;
using Rhino.DocObjects;

namespace Sweep2TestPlugin
{
    public class Sweep2TestCommand : Command
    {
        public Sweep2TestCommand()
        {
            // Rhino only creates one instance of each command class defined in a
            // plug-in, so it is safe to store a refence in a static property.
            Instance = this;
        }

        ///<summary>The only instance of this command.</summary>
        public static Sweep2TestCommand Instance { get; private set; }

        ///<returns>The command name as it appears on the Rhino command line.</returns>
        public override string EnglishName => "Sweep2TestCommand";

        protected override Result RunCommand(RhinoDoc doc, RunMode mode)
        {
            var go = new GetObject();
            go.SetCommandPrompt("Select Rail1");
            go.GeometryFilter = ObjectType.Curve;
            go.Get();
            var go2 = new GetObject();
            go2.SetCommandPrompt("Select Rail2");
            go2.GeometryFilter = ObjectType.Curve;
            go2.EnablePreSelect(false, true);
            go2.Get();
            var go3 = new GetObject();
            go3.SetCommandPrompt("Select Profile");
            go3.GeometryFilter = ObjectType.Curve;
            go3.EnablePreSelect(false, true);
            go3.Get();
            
            var rail1 = go.Object(0).Curve();
            var rail2 = go2.Object(0).Curve();
            var profile = go3.Object(0).Curve();


            var sweepResult = Brep.CreateFromSweep(rail1, rail2, profile, true, 0.001);

            if (sweepResult.Length > 0)
            {
                RhinoDoc.ActiveDoc.Objects.Add(sweepResult[0], new ObjectAttributes() {Name = "sweepResult"});
            }

            // ---
            return Result.Success;
        }

    }
}
